@@ -1,5 +1,5 @@
 test_that("date handling is correct", {
-
+  skip_if_not_installed("jsonify")
   # create sf object
   x <- sf::st_sf(
     data.frame(today = as.POSIXct("2001-01-01", tz = "UTC")),
@@ -7,7 +7,8 @@ test_that("date handling is correct", {
   )
 
   # create json object
-  l <- as_featureset(x)
+  l <- RcppSimdJson::fparse(as_esri_featureset(x))
+  # l <- as_featureset(x)
   # add fields since they are not included by default
   l[["fields"]] <- infer_esri_type(x)
 
@@ -16,5 +17,5 @@ test_that("date handling is correct", {
 
   parsed <- parse_esri_json(json)
 
-  expect_identical(x$today, parsed$today)
+  expect_identical(parsed$today, x$today)
 })
